@@ -1,6 +1,6 @@
 /* ----------------------------------------------------------------------- *
  * 
- * spawn.c - run programs synchronously
+ * spawn.c - run programs synchronously with output redirected to syslog
  *   
  *   Copyright 1997 Transmeta Corporation - All Rights Reserved
  *
@@ -49,7 +49,7 @@ int spawnv(int logpri, char *prog, char **argv) {
   int status, pipefd[2];
   FILE *errs;
   char errbuf[1024], *p;
-  sigset_t allsignals, oldsig;
+  sigset_t allsignals, tmpsig, oldsig;
   
   sigfillset(&allsignals);
   sigprocmask(SIG_BLOCK, &allsignals, &oldsig);
@@ -57,8 +57,11 @@ int spawnv(int logpri, char *prog, char **argv) {
   if ( pipe(pipefd) )
     return -1;
 
-    f = fork();
-  if ( f == 0 ) {
+  f = fork();
+  if ( f < 0 ) {
+    sigprocmask(SIG_SETMASK, &oldsig, NULL);
+    return -1;
+  } else if ( f == 0 ) {
     reset_signals();
     close(pipefd[0]);
     dup2(pipefd[1], STDOUT_FILENO);
@@ -67,7 +70,13 @@ int spawnv(int logpri, char *prog, char **argv) {
     execv(prog, argv);
     _exit(255);	/* execv() failed */
   } else {
-    sigprocmask(SIG_SETMASK, &oldsig, NULL);
+    /* Careful here -- if we enable SIGCHLD yet we may not receive the
+       waitpid() at the end */
+    
+    tmpsig = oldsig;
+
+    sigaddset(&tmpsig, SIGCHLD);
+    sigprocmask(SIG_SETMASK, &tmpsig, NULL);
 
     close(pipefd[1]);
 
@@ -87,9 +96,11 @@ int spawnv(int logpri, char *prog, char **argv) {
       close(pipefd[0]);
 
     if ( waitpid(f, &status, 0) != f )
-      return -1; /* waitpid() failed */
-    else
-      return status;
+      status = -1;		/* waitpid() failed */
+
+    sigprocmask(SIG_SETMASK, &oldsig, NULL);
+
+    return status;
   }
 }
 
