@@ -51,12 +51,12 @@ int mount_mount(char *root, char *name, int name_len, char *what,
   if ( options ) {
     syslog(LOG_DEBUG, MODPREFIX "calling mount -t %s -o %s %s %s",
 	   fstype, options, what, fullpath);
-    err = spawnl(_PATH_MOUNT, _PATH_MOUNT, "-t", fstype, "-o", options,
-		 what, fullpath, NULL);
+    err = spawnl(LOG_NOTICE, _PATH_MOUNT, _PATH_MOUNT, "-t", fstype,
+		 "-o", options, what, fullpath, NULL);
   } else {
     syslog(LOG_DEBUG, MODPREFIX "calling mount -t %s %s %s",
 	   fstype, what, fullpath);
-      err = spawnl(_PATH_MOUNT, _PATH_MOUNT, "-t", fstype,
+      err = spawnl(LOG_NOTICE, _PATH_MOUNT, _PATH_MOUNT, "-t", fstype,
 		   what, fullpath, NULL);
   }
   if ( err ) {
