@@ -87,12 +87,12 @@ static int expandsunent(char *src, char *dst, char *key, struct substvar *svc)
 {
   struct substvar *sv;
   int len, l;
-  char *p;
+  char *p, ch;
 
   len = 0;
 
-  while ( *src ) {
-    switch ( *src ) {
+  while ( (ch = *src++) ) {
+    switch ( ch ) {
     case '&':
       l = strlen(key);
       if ( dst ) {
@@ -100,11 +100,10 @@ static int expandsunent(char *src, char *dst, char *key, struct substvar *svc)
 	dst += l;
       }
       len += l;
-      src++;
       break;
 
     case '$':
-      if ( *(++src) == '{' ) {
+      if ( *src == '{' ) {
 	p = strchr(++src,'}');
 	if ( !p ) {
 	  /* Ignore rest of string */
@@ -137,9 +136,19 @@ static int expandsunent(char *src, char *dst, char *key, struct substvar *svc)
       }
       break;
 
+    case '\\':
+      ch = *src;
+      if ( ch ) {
+	src++;
+	if ( dst ) *(dst++) = ch;
+	len++;
+      } else {
+	; /* Terminal backslash, just eat it */
+      }
+      break;
+
     default:
-      if ( dst ) *(dst++) = *src;
-      src++;
+      if ( dst ) *(dst++) = ch;
       len++;
       break;
     }
